flutter_annotation_http library

Classes

AnnotationClient
CancelToken
DELETE
The DELETE request method deletes the specified resource.
EnableHttpMiddleware
Indicates whether the HTTP middleware feature is enabled
Endpoint
Define an API request
FilePart
A file to be uploaded as part of a Multipart.
GET
The GET method requests a representation of the specified resource. Requests using GET should only be used to request data (they shouldn't include data).
The HEAD method requests the headers that would be returned if the HEAD request's URL was instead requested with the HTTP GET method.
HttpChain
HttpMiddleware
HTTP middleware interface
Middleware
Represents a middleware class
Multipart
A multipart/form-data request.
PATCH
The PATCH request method applies partial modifications to a resource.
PathVariable
Map a placeholder for a URL binding. The {xxx} placeholder in the URL can be bound to the input parameter of a method by @PathVariable ("xxx").
POST
The POST method sends data to the server. The type of the body of the request is indicated by the Content-Type header.
PrintCurlMiddleware
PrintLoggingMiddleware
ProxyHttpOverrides
PUT
The PUT request method creates a new resource or replaces a representation of the target resource with the request payload.
RequestBody
Used to handle content that is not the default application/x-www-form-urlcoded, such as application/json or application/xml.
RequestHeader
Set the method parameters to the request header.
RequestMapping
RequestParam
Used to assign the specified request parameter to a formal parameter in the method.
RetryOptions
A request retries the configuration class

Functions

doWithClient<T>(Future<T> fn(Client), {HttpChain? chain, RetryOptions? retryOptions, int? timeout, CancelToken? cancelToken}) Future<T>

Typedefs

RetryDelay = Duration Function(int)
RetryWhenError = FutureOr<bool> Function(Object, StackTrace)
RetryWhenResponse = FutureOr<bool> Function(BaseResponse)