HttpMiddleware class abstract

HTTP middleware interface

Implementers

Constructors

HttpMiddleware()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRequest(BaseRequest request) Future<BaseRequest>
The request is about to start
onResponse(Response response) Future<Response>
Before the response is returned
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited